==> haskell-smallcheck-1.1.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: smallcheck
version: 1.1.1
id: smallcheck-1.1.1-1P6TVEcRFpCt9hJwyUv6k
key: smallcheck-1.1.1-1P6TVEcRFpCt9hJwyUv6k
license: BSD3
maintainer: Roman Cheplyaka <roma@ro-che.info>
stability: Beta
homepage: https://github.com/feuerbach/smallcheck
synopsis: A property-based testing library
description:
    SmallCheck is a testing library that allows to verify properties
    for all test cases up to some depth. The test cases are generated
    automatically by SmallCheck.
category: Testing
author: Colin Runciman, Roman Cheplyaka
exposed: True
exposed-modules:
    Test.SmallCheck Test.SmallCheck.Drivers Test.SmallCheck.Series
hidden-modules: Test.SmallCheck.Property
                Test.SmallCheck.SeriesMonad Test.SmallCheck.Property.Result
abi: 8015ea8e00811aa81bf64a3ded032a7b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/smallcheck-1.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/smallcheck-1.1.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/smallcheck-1.1.1
hs-libraries: HSsmallcheck-1.1.1-1P6TVEcRFpCt9hJwyUv6k
depends:
    base-4.9.0.0 ghc-prim-0.5.0.0 logict-0.6.0.2-F8Xxo0chmXoLdLqqWhvbew
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pretty-1.1.3.3
haddock-interfaces: /usr/share/doc/haskell-smallcheck/html/smallcheck.haddock
haddock-html: /usr/share/doc/haskell-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-smallcheck-1.1.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: smallcheck
version: 1.1.1
id: smallcheck-1.1.1-5AC9NnxvgVmJHHgJYIqjFF
key: smallcheck-1.1.1-5AC9NnxvgVmJHHgJYIqjFF
license: BSD3
maintainer: Roman Cheplyaka <roma@ro-che.info>
stability: Beta
homepage: https://github.com/feuerbach/smallcheck
synopsis: A property-based testing library
description:
    SmallCheck is a testing library that allows to verify properties
    for all test cases up to some depth. The test cases are generated
    automatically by SmallCheck.
category: Testing
author: Colin Runciman, Roman Cheplyaka
exposed: True
exposed-modules:
    Test.SmallCheck Test.SmallCheck.Drivers Test.SmallCheck.Series
hidden-modules: Test.SmallCheck.Property
                Test.SmallCheck.SeriesMonad Test.SmallCheck.Property.Result
abi: f26d0621e38bf2536aad97067dd90da0
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/smallcheck-1.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/smallcheck-1.1.1
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/smallcheck-1.1.1
hs-libraries: HSsmallcheck-1.1.1-5AC9NnxvgVmJHHgJYIqjFF
depends:
    base-4.9.1.0 ghc-prim-0.5.0.0 logict-0.6.0.2-IvIE0u44i1X7ob5HesINuT
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 pretty-1.1.3.3
haddock-interfaces: /usr/share/doc/haskell-smallcheck/html/smallcheck.haddock
haddock-html: /usr/share/doc/haskell-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
